Welcome to ``spekk``'s auto-generated documentation!
=================================

.. autosummary::
   :toctree: _autosummary
   :template: module-template.rst
   :recursive:

   spekk.spec
   spekk.trees
   spekk.transformations
   spekk.util